@@ -52,12 +52,6 @@ I<inherits from L<WebService::GData>>
 
 This package wraps the link data found in a feed using the json format of the Google Data API v2 (no other format is supported!).
 
-=begin html
-
-<script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery.min.js"></script>
-
-=end html
-
 
 =head1 CONSTRUCTOR
 
